\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{lfg-proc}[2023/07/27 Class for LFG Proceedings papers]

\DeclareOption{10pt}{\OptionNotUsed}
\DeclareOption{12pt}{\OptionNotUsed}
\DeclareOption{letterpaper}{\OptionNotUsed}
\DeclareOption{landscape}{\OptionNotUsed}
\DeclareOption{twocolumn}{\OptionNotUsed}

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax

\LoadClass[11pt,a4paper,fleqn,notitlepage]{article}

\RequirePackage{times}

% Natbib settings
\RequirePackage[sectionbib]{natbib}
\bibpunct{(}{)}{;}{a}{}{,}
\setcitestyle{notesep={:~}} % Changes separator between year and page to colon

% Spacing in bibliography
\setlength{\bibsep}{0.3pt}

% Hyperlink settings
\RequirePackage[hyphens]{url}
%
\urlstyle{same}
\RequirePackage{xcolor}
\definecolor{hlinkcolor}{rgb}{.0,.2,.4} % A nice dark blue
%
\RequirePackage[%
	bookmarks=true,
	bookmarksopen=true,
	hyperindex=true,
	breaklinks=true,
	draft=false,
	plainpages=false,
	hyperfootnotes=false,
	colorlinks=true,
	urlcolor=hlinkcolor,
	pdfborder={0 0 0},
	linkcolor = black,% For internal links
	citecolor = black% For citation links
	]{hyperref}
% \hypersetup{colorlinks=false, pdfborder={0 0 0}}

% No page numbers
\pagestyle{empty}

% Single spacing after full stops
\frenchspacing

% Command to print two-digit year
\newcommand*\shortyear{\expandafter\@gobbletwo\number\numexpr\year\relax}

% % Redefining the author \and command if we want to add text between author blocks
% \renewcommand{\and}{%
% % Original definition:
% % \end{tabular}\hskip 1em \@plus .17fil\begin{tabular}[t]{c}
% \end{tabular}\hskip 0em \@plus .17fil and \hskip 0em \@plus .17fil\begin{tabular}[t]{c}
% }

%===============================================================================
% Our own title page

\renewcommand{\maketitle}{%
\vspace*{1in}

\begin{center}
\Large
		{\huge\bf \@title\par}\vspace{\baselineskip}

\begin{tabular}[t]{c}
\@author
\end{tabular}%
\\[3\baselineskip]

	Proceedings of the LFG'\shortyear{} Conference\\[\baselineskip]

  Miriam Butt,  Jamie Y. Findlay  and Ida Toivonen  (Editors)\\[\baselineskip]


	\the\year{}\\[\baselineskip]

	PubliKon\\[\baselineskip]

	% \url{https://lfg-proceedings.org}
	\href{https://lfg-proceedings.org}{lfg-proceedings.org}

\end{center}

\newpage
}
%===============================================================================

% Acknowledgements footnote
\newcommand{\acknowledgements}[1]{%
\setcounter{footnote}{1}%
\renewcommand{\thefootnote}{\fnsymbol{footnote}}%
\footnote{%
  #1
}%
\renewcommand{\thefootnote}{\arabic{footnote}}%
\setcounter{footnote}{0}%
}
